==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyDefRedClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyDefRedClass

// class file dependencies
// @dep_class 3385cd63de081381 gnu_xml_xpath_XPathParser__24YyDefRedClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyDefRedClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyDefRedClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$object	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$fields_struct {
	_jc_short_array	*yyDefRed;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vmethods	gnu_xml_xpath_XPathParser__24YyDefRedClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_refs	gnu_xml_xpath_XPathParser__24YyDefRedClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyDefRedClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyDefRedClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyDefRedClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyDefRedClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyDefRedClass

// class file dependencies
// @dep_class 3385cd63de081381 gnu_xml_xpath_XPathParser__24YyDefRedClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyDefRedClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyDefRedClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$object	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$fields_struct {
	_jc_short_array	*yyDefRed;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vmethods	gnu_xml_xpath_XPathParser__24YyDefRedClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_refs	gnu_xml_xpath_XPathParser__24YyDefRedClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyDefRedClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyDefRedClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyDefRedClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyDefRedClass_H_ */
